#
# spec file for package gap-semigroups
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gap-semigroups
Version:        2.8.0
Release:        bp153.1.12
Summary:        GAP: Computing with Semigroups of Transformations and Partial Permutations
License:        GPL-2.0+
Group:          Productivity/Scientific/Math
Url:            http://www-groups.mcs.st-and.ac.uk/~jamesm/semigroups

Source:         https://www.gap-system.org/pub/gap/gap4/tar.bz2/packages/semigroups-%version.tar.bz2
BuildArch:      noarch
BuildRequires:  gap-devel >= 4.8.3
BuildRequires:  gap-rpm-devel
BuildRequires:  gmp-devel
BuildRequires:  xz
Requires:       gap-core >= 4.8.3
Requires:       gap-io >= 4.4.4
Requires:       gap-orb >= 4.7.3
Suggests:       gap-gapdoc >= 1.5.1
Suggests:       gap-grape >= 4.5
Suggests:       gap-genss >= 1.5

%description
The Semigroups package is a GAP package containing methods for semigroups,
principally semigroups of transformations, partial permutations or
subsemigroups of regular Rees 0-matrix semigroups. Semigroups contains more
efficient methods than those available in the GAP library (and in many cases
more efficient than any other software) for creating semigroups, calculating
their Green's classes, size, elements, group of units, minimal ideal, small
generating sets, testing membership, finding the inverses of a regular element,
factorizing elements over the generators, and many more. It is also possible to
test if a semigroup satisfies a particular property, such as if it is regular,
simple, inverse, completely regular, and a variety of further properties.

%prep
%setup -qn semigroups-%version

%build

%install
%gappkg_simple_install
find "%buildroot" -name "*.orig" -delete

%files -f %name.files
%defattr(-,root,root)

%changelog
* Mon Jun 20 2016 jengelh@inai.de
- Update to new upstream release 2.8.0
  * Added `ApsisMonoid`, `CrossedApsisMonoid`,
  `ModularPartitionMonoid`, `PlanarModularPartitionMonoid`,
  `PlanarPartitionMonoid`, `PlanarUniformBlockBijectionMonoid`,
  `SingularApsisMonoid`, `SingularCrossedApsisMonoid`,
  `SingularModularPartitionMonoid`,
  `SingularPlanarModularPartitionMonoid`,
  `SingularPlanarPartitionMonoid`,
  `SingularPlanarUniformBlockBijectionMonoid`,
  `SingularUniformBlockBijectionMonoid`,
  `UniformBlockBijectionMonoid`
* Wed Jun  8 2016 jengelh@inai.de
- Update to new upstream release 2.7.4
  * This is a minor release to fix some manual examples, to correct
  the package url in the `PackageInfo.g` file, and to fix some
  issues with semigroups of bipartitions. It was formerly
  possible to create semigroups of bipartitions where the
  generators had different degrees, but the created semigroups
  were invalid; this is fixed in version 2.7.3.
  * Require GAP 4.8.3 since the function `IsZeroSimpleSemigroup`
  entered an infinite loop for some examples of semigroups of
  partial permutations.
* Sat Mar 12 2016 jengelh@inai.de
- Update to new upstream release 2.7.2
  * `IsomorphismReesZeroMatrixSemigroup` is introduced, and it is no
  longer possible to apply `IsomorphismReesMatrixSemigroup` to a
  0-simple semigroup.
  * The meaning of `IsMonoidAsSemigroup` was changed to be consistent
  with the meaning of `IsGroupAsSemigroup`. In earlier versions,
  `IsMonoidAsSemigroup` was `false` for semigroups in the category
  `IsMonoid`.
  * `IsInverseSemigroup` sometimes returned true for semigroups
  which were not inverse
* Sun Feb 22 2015 jengelh@inai.de
- Update to new upstream release 2.2
  * New: the functions SmallestElementSemigroup,
  LargestElementSemigroup, and GeneratorsSmallest.
  * Some minor corrections were made to the methods for creating the
  ideals of some semigroups in standard examples semigroups, such
  as SingularTransformationSemigroup.
* Fri Dec 12 2014 jengelh@inai.de
- Update to new upstream release 2.1.1
  * extensive new features for computing with elements and
  subsemigroups of the partition monoid.
  * support for ideals of transformation, partial permutation, and
  bipartition semigroups, and subsemigroups of Rees 0-matrix
  semigroups.
  * The new operations IsomorphismSemigroups, IsIsomorphicSemigroup,
  and SmallestMultiplicationTable.
  * The new operation MaximalSubsemigroups, which returns the maximal
  subsemigroups of an arbitrary semigroup.
  * The new operation Normalizer for computing a subgroup of a
  permutation group consisting of those permutations that stabilise,
  under conjugation, a transformation, partial perm, or bipartition
  semigroup.
  * The new operation CharacterTableOfInverseSemigroup for finding the
  character table of an inverse semigroup of partial permutations.
  * Methods for defining and manipulating the congruences of a Rees
  0-matrix semigroup.
  * The operation EndomorphismsPartition that returns the monoid
  of endomorphisms preserving a partition. This monoid is defined
  using the minimum possible number of generators.
  * A lot more, see the detailed changelog in the package.
* Tue Feb  4 2014 jengelh@inai.de
- Update to new upstream release 1.4
  * Package rename from citrus to semigroup. The package has been
  completely overhauled, the performance has been improved, and the
  code has been generalized so that in the future the same code can
  be used to compute with other types of semigroups.
  * This release includes several new methods for inverse semigroups
  of partial permutations and for free inverse semigroup. Most
  notably among the new methods for inverse semigroups of partial
  permutations are: "SmallerDegreePartialPermRepresentation" and
  "VagnerPrestonRepresentation" for changing the representation of
  an inverse semigroup of partial permutations.
  * The methods in Semigroups have been extended to apply to
  arbitrary subsemigroups of regular Rees 0-matrix semigroups over
  groups;
  * A new method for MaximalSubsemigroups of Rees matrix semigroup
  has been implemented;
  * The function Read/WriteSemigroups have been renamed
  Read/WriteGenerators and their performance has been improved. It
  is now possible to use WriteGenerators to write to a gzipped file.
* Fri May 10 2013 jengelh@inai.de
- Split citrus (version 0.9999) off the gap RPM package
